==> Video_Audio_Image_Downloader-0.1.1.tar.gz: Video_Audio_Image_Downloader-0.1.1/README.md <==
# Downloder - To download Video and Audio and Any type of Images

`Downloader` is a Downloading tool,is used to `download the Youtube Video's`With specified path with specified Resolution.
It is used to `download the Audio's` with specified path with specified name of the Audio file and `Download the images` with any type of image's with their image source address or image address

## Prerequisites


On Ubuntu/Debian:


    sudo apt install update
    sudo apt install upgrade


## Installation

Use pip/pip3 to install from PyPI

    $ pip install Video-Audio-Image-Downloader

You can also use Python from your command prompt

    $ python -m pip install Video-Audio-Image-Downloader

## Usage of `Downloader`


To download the Youtube video's and Audio's And Download Any type of Image's.

    Downloader [Option..]


With `Downloader`, you can download any YouTube Video and Audio you want, over a few commands. The following section of the documentation is to guide you on how to use `Downloder` tool.


### Download YouTube Videos

To Download a YouTube Video from your default web browser or Direct from Youtube Platform , use the following syntax:

    Usage: Downloader Youtube Video [-source="Youtube video link" -resolution="Youtube video resolution" -path="file path"]

    Positional arguments:

            -source
                        Source or Link of the Video file

    optional arguments:

            -resolution
                            The Resolution of the Video's to Download.
                            For now, the default value 730p.

            -path           
                            The Path of the Video's to download.
                            For now,The default path is your Current Working Directory

            -h,--help
                            List information about the Command


##### Get the Resolution of the Video file
To get a YouTube Video Resolution of the Video file, use the following syntax:

    Usage: Downloader Youtube Video  -get_resolution [-get_url="Source of the Video file"]
        
        
    Positional arguments:

            -get_url
                    We provide the source of the Video file's

    optional arguments:
            -h,--help
                    List information about the Command


##### To Get All Information about the  Video file
To get all information about the YouTube Video file, use the following syntax:

    Usage: Downloader Youtube Video  Description [-url="Source of the Video file"]
        
        
    Positional arguments:

            -url
                    We provide the source of the Video file's

    optional arguments:
            -h,--help
                    List information about the Command
            


### Download YouTube Audios

To Download a YouTube Audio from your default web browser or Direct from Youtube Platform , use the following syntax:

    Usage: Downloader Youtube Audio [-source="Youtube Audio link" ]
    
    Positional arguments:

            -source
                        Source or Link of the Audio file

    optional arguments:

            -path           
                            The Path of the Audio's to download.
                            For now,The default path is your Current Working Directory



##### Download Any type of Images

To Download Any type of Images from your default web browser or Any type of online  Platform , use the following syntax:

    Usage: Downloader Image [-source="Image address link" -filename="Your Image filename"]


    Positional arguments:

            -source
                        Source or Link of the Audio file

            -filename
                        Name of the file

    optional arguments:

            -path           
                            The Path of the Image to  be download.
                            For now,The default path is your Current Working Directory

==> Video_Audio_Image_Downloader-0.1.2.tar.gz: Video_Audio_Image_Downloader-0.1.2/README.md <==
# Downloder - To download Video and Audio and Any type of Images

`Downloader` is a Downloading tool,is used to `download the Youtube Video's`With specified path with specified Resolution.
It is used to `download the Audio's` with specified path with specified name of the Audio file and `Download the images` with any type of image's with their image source address or image address

## Prerequisites


On Ubuntu/Debian:


    sudo apt install update
    sudo apt install upgrade


## Installation

Use pip/pip3 to install from PyPI

    $ pip install Video-Audio-Image-Downloader

You can also use Python from your command prompt

    $ python -m pip install Video-Audio-Image-Downloader

## Usage of `Downloader`


To download the Youtube video's and Audio's And Download Any type of Image's.

    Downloader [Option..]


With `Downloader`, you can download any YouTube Video and Audio you want, over a few commands. The following section of the documentation is to guide you on how to use `Downloder` tool.


### Download YouTube Videos

To Download a YouTube Video from your default web browser or Direct from Youtube Platform , use the following syntax:

    Usage: Downloader Youtube Video [-source="Youtube video link" -resolution="Youtube video resolution" -path="file path"]

    Positional arguments:

            -source
                        Source or Link of the Video file

    optional arguments:

            -resolution
                            The Resolution of the Video's to Download.
                            For now, the default value 730p.

            -path           
                            The Path of the Video's to download.
                            For now,The default path is your Current Working Directory

            -h,--help
                            List information about the Command


##### Get the Resolution of the Video file
To get a YouTube Video Resolution of the Video file, use the following syntax:

    Usage: Downloader Youtube Video  -get_resolution [-get_url="Source of the Video file"]
        
        
    Positional arguments:

            -get_url
                    We provide the source of the Video file's

    optional arguments:
            -h,--help
                    List information about the Command


##### To Get All Information about the  Video file
To get all information about the YouTube Video file, use the following syntax:

    Usage: Downloader Youtube Video  Description [-url="Source of the Video file"]
        
        
    Positional arguments:

            -url
                    We provide the source of the Video file's

    optional arguments:
            -h,--help
                    List information about the Command
            


### Download YouTube Audios

To Download a YouTube Audio from your default web browser or Direct from Youtube Platform , use the following syntax:

    Usage: Downloader Youtube Audio [-source="Youtube Audio link" ]
    
    Positional arguments:

            -source
                        Source or Link of the Audio file

    optional arguments:

            -path           
                            The Path of the Audio's to download.
                            For now,The default path is your Current Working Directory



### Download Any type of Images

To Download Any type of Images from your default web browser or Any type of online  Platform , use the following syntax:

    Usage: Downloader Image [-source="Image address link" -filename="Your Image filename"]


    Positional arguments:

            -source
                        Source or Link of the Audio file

            -filename
                        Name of the file

    optional arguments:

            -path           
                            The Path of the Image to  be download.
                            For now,The default path is your Current Working Directory

### Contact 
    1. Email - dcsvsridhar@gmail.com
